@@ -18,8 +18,7 @@ class KDECONNECTCORE_EXPORT Server : public QTcpServer
     Q_OBJECT
 
 public:
-    Server(QObject *parent = 0);
-    ~Server() override = default;
+    Server(QObject *parent = nullptr);
 
     QSslSocket *nextPendingConnection() override;
     void close();
