@@ -4,6 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include <QApplication>
 #include <QDebug>
 #include <QFile>
 #include <QIcon>
@@ -14,17 +15,15 @@
 
 #include <Windows.h>
 #include <tlhelp32.h>
-
 #include <winrt/Windows.Foundation.Collections.h>
 #include <winrt/Windows.UI.ViewManagement.h>
 
 #include "indicator_debug.h"
 #include "indicatorhelper.h"
-
 winrt::Windows::UI::ViewManagement::UISettings uiSettings;
 
-IndicatorHelper::IndicatorHelper(const QUrl &indicatorUrl)
-    : m_indicatorUrl(indicatorUrl)
+IndicatorHelper::IndicatorHelper()
+    : m_indicatorUrl(QUrl::fromLocalFile(QApplication::applicationDirPath()))
 {
     uiSettings = winrt::Windows::UI::ViewManagement::UISettings();
 }
@@ -39,14 +38,6 @@ IndicatorHelper::~IndicatorHelper()
     this->terminateProcess(processes::kdeconnect_daemon, m_indicatorUrl);
 }
 
-void IndicatorHelper::preInit()
-{
-}
-
-void IndicatorHelper::postInit()
-{
-}
-
 void IndicatorHelper::iconPathHook()
 {
     // FIXME: This doesn't seem to be enough for QIcon::fromTheme to find the icons, so we still have to use the full path when setting the icon
@@ -58,7 +49,7 @@ void IndicatorHelper::iconPathHook()
     }
 }
 
-int IndicatorHelper::daemonHook(QProcess &kdeconnectd)
+int IndicatorHelper::startDaemon()
 {
     kdeconnectd.start(processes::kdeconnect_daemon, QStringList());
     return 0;
