@@ -9,26 +9,26 @@
 
 #include "kdeconnectinterfaces_export.h"
 
-#include "batteryinterface.h"
-#include "bigscreeninterface.h"
-#include "connectivityinterface.h"
-#include "conversationsinterface.h"
-#include "daemoninterface.h"
-#include "devicefindmyphoneinterface.h"
-#include "deviceinterface.h"
-#include "devicenotificationsinterface.h"
-#include "devicesftpinterface.h"
-#include "lockdeviceinterface.h"
-#include "mprisremoteinterface.h"
-#include "notificationinterface.h"
-#include "remotecommandsinterface.h"
-#include "remotecontrolinterface.h"
-#include "remotekeyboardinterface.h"
-#include "remotesystemvolumeinterface.h"
-#include "shareinterface.h"
-#include "smsinterface.h"
-#include "virtualmonitorinterface.h"
-#include "photointerface.h"
+#include "generated/batteryinterface.h"
+#include "generated/bigscreeninterface.h"
+#include "generated/connectivityinterface.h"
+#include "generated/conversationsinterface.h"
+#include "generated/daemoninterface.h"
+#include "generated/deviceclipboardinterface.h"
+#include "generated/devicefindmyphoneinterface.h"
+#include "generated/deviceinterface.h"
+#include "generated/devicenotificationsinterface.h"
+#include "generated/devicesftpinterface.h"
+#include "generated/lockdeviceinterface.h"
+#include "generated/mprisremoteinterface.h"
+#include "generated/notificationinterface.h"
+#include "generated/remotecommandsinterface.h"
+#include "generated/remotecontrolinterface.h"
+#include "generated/remotekeyboardinterface.h"
+#include "generated/remotesystemvolumeinterface.h"
+#include "generated/shareinterface.h"
+#include "generated/smsinterface.h"
+#include "generated/virtualmonitorinterface.h"
 
 /**
  * Using these "proxy" classes just in case we need to rename the
@@ -40,38 +40,35 @@ class KDECONNECTINTERFACES_EXPORT DaemonDbusInterface : public OrgKdeKdeconnectD
     Q_PROPERTY(QStringList customDevices READ customDevices WRITE setCustomDevices NOTIFY customDevicesChangedProxy)
 public:
     explicit DaemonDbusInterface(QObject *parent = nullptr);
-    ~DaemonDbusInterface() override;
 
     static QString activatedService();
 
 Q_SIGNALS:
-    void deviceAdded(const QString &id);
-    void pairingRequestsChangedProxy();
     void customDevicesChangedProxy();
 };
 
 class KDECONNECTINTERFACES_EXPORT DeviceDbusInterface : public OrgKdeKdeconnectDeviceInterface
 {
     Q_OBJECT
-    //  TODO: Workaround because OrgKdeKdeconnectDeviceInterface is not generating
-    //  the signals for the properties
+    // Workaround because qdbusxml2cpp is not generating NOTIFY for properties
     Q_PROPERTY(bool isReachable READ isReachable NOTIFY reachableChangedProxy)
-    Q_PROPERTY(bool isTrusted READ isTrusted NOTIFY trustedChangedProxy)
+    Q_PROPERTY(bool isPaired READ isPaired NOTIFY pairStateChangedProxy)
+    Q_PROPERTY(bool isPairRequested READ isPairRequested NOTIFY pairStateChangedProxy)
+    Q_PROPERTY(bool isPairRequestedByPeer READ isPairRequestedByPeer NOTIFY pairStateChangedProxy)
+    Q_PROPERTY(int pairState READ pairState NOTIFY pairStateChangedProxy)
     Q_PROPERTY(QString name READ name NOTIFY nameChangedProxy)
-    Q_PROPERTY(bool hasPairingRequests READ hasPairingRequests NOTIFY hasPairingRequestsChangedProxy)
+    Q_PROPERTY(QString verificationKey READ verificationKey NOTIFY pairStateChangedProxy)
 
 public:
     explicit DeviceDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~DeviceDbusInterface() override;
 
     Q_SCRIPTABLE QString id() const;
     Q_SCRIPTABLE void pluginCall(const QString &plugin, const QString &method);
 
 Q_SIGNALS:
     void nameChangedProxy(const QString &name);
-    void trustedChangedProxy(bool paired);
+    void pairStateChangedProxy(int pairState);
     void reachableChangedProxy(bool reachable);
-    void hasPairingRequestsChangedProxy(bool);
 
 private:
     const QString m_id;
@@ -84,7 +81,6 @@ class KDECONNECTINTERFACES_EXPORT BatteryDbusInterface : public OrgKdeKdeconnect
     Q_PROPERTY(bool isCharging READ isCharging NOTIFY refreshedProxy)
 public:
     explicit BatteryDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~BatteryDbusInterface() override;
 
 Q_SIGNALS:
     void refreshedProxy(bool isCharging, int charge);
@@ -97,7 +93,6 @@ class KDECONNECTINTERFACES_EXPORT ConnectivityReportDbusInterface : public OrgKd
     Q_PROPERTY(int cellularNetworkStrength READ cellularNetworkStrength NOTIFY refreshedProxy)
 public:
     explicit ConnectivityReportDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~ConnectivityReportDbusInterface() override;
 
 Q_SIGNALS:
     void refreshedProxy(QString cellularNetworkType, int cellularNetworkStrength);
@@ -108,7 +103,6 @@ class KDECONNECTINTERFACES_EXPORT DeviceNotificationsDbusInterface : public OrgK
     Q_OBJECT
 public:
     explicit DeviceNotificationsDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~DeviceNotificationsDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT NotificationDbusInterface : public OrgKdeKdeconnectDeviceNotificationsNotificationInterface
@@ -116,7 +110,6 @@ class KDECONNECTINTERFACES_EXPORT NotificationDbusInterface : public OrgKdeKdeco
     Q_OBJECT
 public:
     NotificationDbusInterface(const QString &deviceId, const QString &notificationId, QObject *parent = nullptr);
-    ~NotificationDbusInterface() override;
 
     QString notificationId()
     {
@@ -132,7 +125,6 @@ class KDECONNECTINTERFACES_EXPORT DeviceConversationsDbusInterface : public OrgK
     Q_OBJECT
 public:
     explicit DeviceConversationsDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~DeviceConversationsDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT SftpDbusInterface : public OrgKdeKdeconnectDeviceSftpInterface
@@ -140,17 +132,14 @@ class KDECONNECTINTERFACES_EXPORT SftpDbusInterface : public OrgKdeKdeconnectDev
     Q_OBJECT
 public:
     explicit SftpDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~SftpDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT MprisDbusInterface : public OrgKdeKdeconnectDeviceMprisremoteInterface
 {
     Q_OBJECT
-    //  TODO: Workaround because qdbusxml2cpp is not generating
-    //  the signals for the properties
+    // Workaround because qdbusxml2cpp is not generating NOTIFY for properties
     Q_PROPERTY(bool isPlaying READ isPlaying NOTIFY propertiesChangedProxy)
     Q_PROPERTY(int length READ length NOTIFY propertiesChangedProxy)
-    Q_PROPERTY(QString nowPlaying READ nowPlaying NOTIFY propertiesChangedProxy)
     Q_PROPERTY(QString title READ title NOTIFY propertiesChangedProxy)
     Q_PROPERTY(QString artist READ artist NOTIFY propertiesChangedProxy)
     Q_PROPERTY(QString album READ album NOTIFY propertiesChangedProxy)
@@ -161,7 +150,6 @@ class KDECONNECTINTERFACES_EXPORT MprisDbusInterface : public OrgKdeKdeconnectDe
     Q_PROPERTY(bool canSeek READ canSeek NOTIFY propertiesChangedProxy)
 public:
     explicit MprisDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~MprisDbusInterface() override;
 
 Q_SIGNALS:
     void propertiesChangedProxy();
@@ -172,7 +160,6 @@ class KDECONNECTINTERFACES_EXPORT RemoteControlDbusInterface : public OrgKdeKdec
     Q_OBJECT
 public:
     explicit RemoteControlDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~RemoteControlDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT LockDeviceDbusInterface : public OrgKdeKdeconnectDeviceLockdeviceInterface
@@ -181,7 +168,6 @@ class KDECONNECTINTERFACES_EXPORT LockDeviceDbusInterface : public OrgKdeKdeconn
     Q_PROPERTY(bool isLocked READ isLocked WRITE setIsLocked NOTIFY lockedChangedProxy)
 public:
     explicit LockDeviceDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~LockDeviceDbusInterface() override;
 
 Q_SIGNALS:
     void lockedChangedProxy(bool isLocked);
@@ -192,26 +178,26 @@ class KDECONNECTINTERFACES_EXPORT FindMyPhoneDeviceDbusInterface : public OrgKde
     Q_OBJECT
 public:
     explicit FindMyPhoneDeviceDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~FindMyPhoneDeviceDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT RemoteCommandsDbusInterface : public OrgKdeKdeconnectDeviceRemotecommandsInterface
 {
     Q_OBJECT
+    // Workaround because qdbusxml2cpp is not generating CONSTANT for properties and qml complains at runtime
+    Q_PROPERTY(QString deviceId READ deviceId CONSTANT)
+    Q_PROPERTY(bool canAddCommand READ canAddCommand CONSTANT)
 public:
     explicit RemoteCommandsDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~RemoteCommandsDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT RemoteKeyboardDbusInterface : public OrgKdeKdeconnectDeviceRemotekeyboardInterface
 {
     Q_OBJECT
-    Q_PROPERTY(bool remoteState READ remoteState NOTIFY remoteStateChanged)
+    Q_PROPERTY(bool remoteState READ remoteState NOTIFY remoteStateChangedProxy)
 public:
     explicit RemoteKeyboardDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~RemoteKeyboardDbusInterface() override;
 Q_SIGNALS:
-    void remoteStateChanged(bool state);
+    void remoteStateChangedProxy(bool state);
 };
 
 class KDECONNECTINTERFACES_EXPORT SmsDbusInterface : public OrgKdeKdeconnectDeviceSmsInterface
@@ -219,7 +205,6 @@ class KDECONNECTINTERFACES_EXPORT SmsDbusInterface : public OrgKdeKdeconnectDevi
     Q_OBJECT
 public:
     explicit SmsDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~SmsDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT ShareDbusInterface : public OrgKdeKdeconnectDeviceShareInterface
@@ -227,25 +212,15 @@ class KDECONNECTINTERFACES_EXPORT ShareDbusInterface : public OrgKdeKdeconnectDe
     Q_OBJECT
 public:
     explicit ShareDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~ShareDbusInterface() override;
 };
 
-class KDECONNECTINTERFACES_EXPORT PhotoDbusInterface
-    : public OrgKdeKdeconnectDevicePhotoInterface
-{
-    Q_OBJECT
-public:
-    explicit PhotoDbusInterface(const QString& deviceId, QObject* parent = nullptr);
-    ~PhotoDbusInterface() override;
-};
-
-class KDECONNECTINTERFACES_EXPORT RemoteSystemVolumeDbusInterface
-    : public OrgKdeKdeconnectDeviceRemotesystemvolumeInterface
+class KDECONNECTINTERFACES_EXPORT RemoteSystemVolumeDbusInterface : public OrgKdeKdeconnectDeviceRemotesystemvolumeInterface
 {
     Q_OBJECT
+    // Workaround because qdbusxml2cpp is not generating CONSTANT for properties and qml complains at runtime
+    Q_PROPERTY(QString deviceId READ deviceId CONSTANT)
 public:
     explicit RemoteSystemVolumeDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~RemoteSystemVolumeDbusInterface() override = default;
 };
 
 class KDECONNECTINTERFACES_EXPORT BigscreenDbusInterface : public OrgKdeKdeconnectDeviceBigscreenInterface
@@ -253,7 +228,6 @@ class KDECONNECTINTERFACES_EXPORT BigscreenDbusInterface : public OrgKdeKdeconne
     Q_OBJECT
 public:
     explicit BigscreenDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~BigscreenDbusInterface() override;
 };
 
 class KDECONNECTINTERFACES_EXPORT VirtualmonitorDbusInterface : public OrgKdeKdeconnectDeviceVirtualmonitorInterface
@@ -261,18 +235,16 @@ class KDECONNECTINTERFACES_EXPORT VirtualmonitorDbusInterface : public OrgKdeKde
     Q_OBJECT
 public:
     explicit VirtualmonitorDbusInterface(const QString &deviceId, QObject *parent = nullptr);
-    ~VirtualmonitorDbusInterface() override;
 };
 
-template<typename T, typename W>
-static void setWhenAvailable(const QDBusPendingReply<T> &pending, W func, QObject *parent)
+class KDECONNECTINTERFACES_EXPORT ClipboardDbusInterface : public OrgKdeKdeconnectDeviceClipboardInterface
 {
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pending, parent);
-    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, parent, [func](QDBusPendingCallWatcher *watcher) {
-        watcher->deleteLater();
-        QDBusPendingReply<T> reply = *watcher;
-        func(reply.value());
-    });
-}
+    Q_OBJECT
+    Q_PROPERTY(bool isAutoShareDisabled READ isAutoShareDisabled NOTIFY autoShareDisabledChangedProxy)
+public:
+    explicit ClipboardDbusInterface(const QString &deviceId, QObject *parent = nullptr);
+Q_SIGNALS:
+    void autoShareDisabledChangedProxy(bool b);
+};
 
 #endif
