@@ -12,11 +12,14 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginMetaData>
+#include <QMessageBox>
+#include <QtWidgets/QListView>
 #include <kcmutils_version.h>
 
 #include <QQmlContext>
 #include <QQuickItem>
 #include <QQuickStyle>
+#include <qassert.h>
 
 #include "dbushelpers.h"
 #include "dbusinterfaces.h"
@@ -92,12 +95,88 @@ KdeConnectKcm::KdeConnectKcm(QObject *parent, const KPluginMetaData &md, const Q
             }
         },
         this);
+
+    setWhenAvailable(
+        daemon->linkProviders(),
+        [this](bool error, const QStringList &linkProviders) {
+            if (error) {
+                return;
+            }
+            kcmUi.linkProviders_list->clear();
+            if (linkProviders.size() <= 1) {
+                kcmUi.linkProviders_list->hide();
+                kcmUi.linkProviders_label->hide();
+            } else {
+                for (int i = 0; i < linkProviders.size(); ++i) {
+                    const QStringList linkProvider = linkProviders.at(i).split(QStringLiteral("|"));
+                    const QString providerId = linkProvider.at(0);
+                    QString displayName;
+                    if (providerId == QLatin1StringView("BluetoothLinkProvider")) {
+                        displayName = i18nc("@info KDE Connect provider name", "Bluetooth");
+                    } else if (providerId == QLatin1StringView("LoopbackLinkProvider")) {
+                        displayName = i18nc("@info KDE Connect provider name", "Loopback");
+                    } else if (providerId == QLatin1StringView("LanLinkProvider")) {
+                        displayName = i18nc("@info KDE Connect provider name", "Network");
+                    } else {
+                        Q_ASSERT_X(false, Q_FUNC_INFO, "Unknow provider given");
+                        displayName = i18nc("@info KDE Connect provider name", "Unknown");
+                    }
+                    QString providerStatus = linkProvider.at(1);
+
+                    QListWidgetItem *linkProviderItem = new QListWidgetItem(displayName, kcmUi.linkProviders_list);
+                    linkProviderItem->setData(Qt::UserRole, providerId);
+
+                    if (providerStatus.compare(QStringLiteral("enabled")) == 0) {
+                        linkProviderItem->setCheckState(Qt::Checked);
+                    } else {
+                        linkProviderItem->setCheckState(Qt::Unchecked);
+                    }
+
+                    kcmUi.linkProviders_list->addItem(linkProviderItem);
+                }
+            }
+
+            connect(kcmUi.linkProviders_list, &QListWidget::itemChanged, this, [this](const QListWidgetItem *item) {
+                bool checked = item->checkState() == Qt::Checked;
+                daemon->setLinkProviderState(item->data(Qt::UserRole).toString(), checked);
+            });
+        },
+        this);
+
     connect(daemon, &DaemonDbusInterface::announcedNameChanged, kcmUi.rename_edit, &QLineEdit::setText);
     connect(daemon, &DaemonDbusInterface::announcedNameChanged, kcmUi.rename_label, &QLabel::setText);
+
+    connect(daemon, &DaemonDbusInterface::linkProvidersChanged, this, [this](const QStringList &providers) {
+        if (kcmUi.linkProviders_list->count() == 0) {
+            return; // not yet setup
+        }
+        for (auto i = 0, count = kcmUi.linkProviders_list->count(); i < count; i++) {
+            const auto item = kcmUi.linkProviders_list->item(i);
+            const auto id = item->data(Qt::UserRole).toString();
+
+            bool found = false;
+            for (const auto &provider : providers) {
+                if (provider.startsWith(id)) {
+                    const auto status = provider.split(QStringLiteral("|")).at(1);
+                    if (status.compare(QStringLiteral("enabled")) == 0) {
+                        item->setCheckState(Qt::Checked);
+                    } else {
+                        item->setCheckState(Qt::Unchecked);
+                    }
+                    found = true;
+                    break;
+                }
+            }
+
+            Q_ASSERT_X(found, Q_FUNC_INFO, "A new backend appeared, this should not happen as the list of backends is static");
+        }
+    });
+
     setRenameMode(false);
 
     setButtons(KCModule::Help | KCModule::NoAdditionalButton);
 
+    connect(devicesModel, &QAbstractItemModel::rowsRemoved, this, &KdeConnectKcm::devicesRemoved);
     connect(kcmUi.accept_button, &QAbstractButton::clicked, this, &KdeConnectKcm::acceptPairing);
     connect(kcmUi.reject_button, &QAbstractButton::clicked, this, &KdeConnectKcm::cancelPairing);
     connect(kcmUi.cancel_button, &QAbstractButton::clicked, this, &KdeConnectKcm::cancelPairing);
@@ -127,6 +206,19 @@ KdeConnectKcm::KdeConnectKcm(QObject *parent, const KPluginMetaData &md, const Q
     }
 }
 
+void KdeConnectKcm::devicesRemoved()
+{
+    if (!currentDevice) {
+        return;
+    }
+    // If current device no longer exists, unselect it
+    if (devicesModel->rowForDevice(currentDevice->id()) == -1) {
+        currentDevice = nullptr;
+        kcmUi.deviceInfo->setVisible(false);
+        delete currentDevice;
+    }
+}
+
 void KdeConnectKcm::renameShow()
 {
     setRenameMode(true);
@@ -201,8 +293,6 @@ void KdeConnectKcm::resetCurrentDevice()
 
 void KdeConnectKcm::resetDeviceView()
 {
-    kcmUi.verificationKey->setText(i18n("Key: %1", currentDevice->verificationKey()));
-
     kcmUi.name_label->setText(currentDevice->name());
     setWhenAvailable(
         currentDevice->pairStateAsInt(),
@@ -287,6 +377,7 @@ void KdeConnectKcm::setCurrentDevicePairState(int pairStateAsInt)
     kcmUi.unpair_button->setVisible(state == PairState::Paired);
     kcmUi.progressBar->setVisible(state == PairState::Requested);
     kcmUi.ping_button->setVisible(state == PairState::Paired);
+    kcmUi.verificationKey->setVisible(state == PairState::Requested || state == PairState::RequestedByPeer);
     switch (state) {
     case PairState::Paired:
         kcmUi.status_label->setText(i18n("(paired)"));
@@ -296,9 +387,11 @@ void KdeConnectKcm::setCurrentDevicePairState(int pairStateAsInt)
         break;
     case PairState::RequestedByPeer:
         kcmUi.status_label->setText(i18n("(incoming pair request)"));
+        kcmUi.verificationKey->setText(i18n("Key: %1", currentDevice->verificationKey()));
         break;
     case PairState::Requested:
         kcmUi.status_label->setText(i18n("(pairing requested)"));
+        kcmUi.verificationKey->setText(i18n("Key: %1", currentDevice->verificationKey()));
         break;
     }
 }
